use actix_web::{Responder, Result, delete, get, post, web};
use log::info;
use sea_orm::prelude::Uuid;
use serde::Deserialize;

use crate::db::Database;
use crate::error::ApiError;

#[derive(Deserialize)]
struct CreateProject {
    name: String,
}

pub fn setup(cfg: &mut actix_web::web::ServiceConfig) {
    cfg.service(create_project)
        .service(delete_project)
        .service(get_projects);
}

#[post("")]
async fn create_project(
    db: web::Data<Database>,
    create_project_struct: web::Json<CreateProject>,
) -> Result<web::Json<entity::project::Model>, ApiError> {
    let result = db.create_project(&create_project_struct.name).await?;

    Ok(web::Json(result))
}

#[delete("/{id}")]
async fn delete_project(
    db: web::Data<Database>,
    path: web::Path<Uuid>,
) -> Result<web::Json<String>, ApiError> {
    let id = path.into_inner();
    let result = db.delete_project(&id).await?;

    Ok(web::Json(format!(
        "Successfully deleted {} project/s with the id: {}",
        result.rows_affected, id
    )))
}

#[get("")]
async fn get_projects() -> impl Responder {
    ""
}
