use super::Database;
use crate::error::ApiError;
use log::info;

use entity::project;
use sea_orm::ActiveValue::{NotSet, Set};
use sea_orm::prelude::Uuid;
use sea_orm::{ActiveModelTrait, DeleteResult, EntityTrait};

impl Database {
    pub async fn create_project(&self, name: &str) -> Result<project::Model, ApiError> {
        let project = project::ActiveModel {
            id: NotSet,
            name: Set(name.to_owned()),
        };

        let project = project.insert(&self.conn).await?;
        Ok(project)
    }

    pub async fn delete_project(&self, id: &Uuid) -> Result<DeleteResult, ApiError> {
        info!("Deleting project with id: {}", id);

        let project = project::Entity::delete_by_id(id.to_owned())
            .exec(&self.conn)
            .await?;

        if project.rows_affected == 0 {
            return Err(ApiError::NotFound);
        }

        Ok(project)
    }
}
